#!/usr/bin/env python

class FileExistResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually."""


    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {
            'FileExist': 'FileExist',
            'Code': 'int',
            'Status': 'str'

        }

        self.attributeMap = {
            'FileExist': 'FileExist','Code': 'Code','Status': 'Status'}       

        self.FileExist = None # FileExist
        self.Code = None # int
        self.Status = None # str
        



import unittest
import os.path
import json

from asposestoragecloud.ApiClient import ApiClient
from asposestoragecloud.StorageApi import StorageApi
from asposestoragecloud.ApiClient import ApiException
from asposestoragecloud.models import ResponseMessage
from asposestoragecloud.models import DiscUsageResponse
from asposestoragecloud.models import FileExistResponse
from asposestoragecloud.models import MoveFileResponse
from asposestoragecloud.models import MoveFolderResponse
from asposestoragecloud.models import StorageExistResponse
from asposestoragecloud.models import FileVersionsResponse
from asposestoragecloud.models import RemoveFolderResponse
from asposestoragecloud.models import RemoveFileResponse

class TestAsposeStorage(unittest.TestCase):

    def setUp(self):

        with open('setup.json') as json_file:
            data = json.load(json_file)

        self.apiClient = ApiClient(apiKey=str(data['app_key']),appSid=str(data['app_sid']),debug=True,apiServer=str(data['product_uri']))
        self.storageApi = StorageApi(self.apiClient)

        self.output_path = str(data['output_location'])

    def testGetListFiles(self):
        
        try:
            response = self.storageApi.PutCreateFolder('list_test_folder')
            response = self.storageApi.PutCreate('list_test_folder/SampleWordDocument.docx','./data/SampleWordDocument.docx')
            response = self.storageApi.PutCreate('list_test_folder/testfile.txt','./data/testfile.txt')
            response = self.storageApi.PutCreateFolder('list_test_folder/sub_folder')
            response = self.storageApi.GetListFiles(Path='list_test_folder')
            self.assertEqual(len(response.Files),3)
            self.assertEqual(response.Status,'OK')
        except ApiException as ex:
            print "Exception"
            print "Code: " + str(ex.code)
            print "Mesage: " + ex.message
            raise ex

    def testGetDiscUsage(self):
        try:
            response = self.storageApi.GetDiscUsage()

            self.assertIsInstance(response,DiscUsageResponse.DiscUsageResponse)
            self.assertEqual(response.Status,'OK')
        except ApiException as ex:
            print "Exception"
            print "Code: " + str(ex.code)
            print "Mesage: " + ex.message
            raise ex

    def testPutCreate(self):
        try:
            response = self.storageApi.PutCreate('SampleWordDocument.docx','./data/SampleWordDocument.docx')

            self.assertIsInstance(response,ResponseMessage.ResponseMessage)
            self.assertEqual(response.Status,'OK')
        except ApiException as ex:
            print "Exception"
            print "Code: " + str(ex.code)
            print "Mesage: " + ex.message
            raise ex

    def testGetDownload(self):
        try:
            response = self.storageApi.GetDownload('SampleWordDocument.docx')

            self.assertEqual(response.Status,'OK')

            with open("./output/" + 'SampleWordDocument.docx', 'wb') as f:
                for chunk in response.InputStream:
                    f.write(chunk)


            self.assertTrue(True, os.path.exists("./output/" + 'SampleWordDocument.docx'))

        except ApiException as ex:
            print "Exception"
            print "Code: " + str(ex.code)
            print "Mesage: " + ex.message
            raise ex

    def testGetIsExist(self):
        try:
            response = self.storageApi.GetIsExist('testfile.txt')

            self.assertIsInstance(response,FileExistResponse.FileExistResponse)
            self.assertEqual(response.Status,'OK')
        except ApiException as ex:
            print "Exception"
            print "Code: " + str(ex.code)
            print "Mesage: " + ex.message
            raise ex

    def testPutCreateFolder(self):
        try:
            response = self.storageApi.PutCreateFolder('mytestfolder')

            self.assertIsInstance(response,ResponseMessage.ResponseMessage)
            self.assertEqual(response.Status,'OK')
        except ApiException as ex:
            print "Exception"
            print "Code: " + str(ex.code)
            print "Mesage: " + ex.message
            raise ex

    def testPostMoveFile(self):
        try:
            response = self.storageApi.PutCreate('testfile.txt','./data/testfile.txt')
            response = self.storageApi.PostMoveFile('testfile.txt','mytestfolder/testfile.txt')

            self.assertIsInstance(response,MoveFileResponse.MoveFileResponse)
            self.assertEqual(response.Status,'OK')

        except ApiException as ex:
            print "Exception"
            print "Code: " + str(ex.code)
            print "Mesage: " + ex.message
            raise ex

    def testPostMoveFolder(self):
        try:
            response = self.storageApi.PostMoveFolder('mytestfolder','mytestfolder_new')

            self.assertIsInstance(response,MoveFolderResponse.MoveFolderResponse)
            self.assertEqual(response.Status,'OK')

        except ApiException as ex:
            print "Exception"
            print "Code: " + str(ex.code)
            print "Mesage: " + ex.message
            raise ex

    def testPutCopy(self):
        try:
            response = self.storageApi.PutCreate('testfile.txt','./data/testfile.txt')
            response = self.storageApi.PutCopy('testfile.txt','new_testfile.txt','./data/testfile.txt')

            self.assertIsInstance(response,ResponseMessage.ResponseMessage)
            self.assertEqual(response.Status,'OK')
        except ApiException as ex:
            print "Exception"
            print "Code: " + str(ex.code)
            print "Mesage: " + ex.message
            raise ex

    def testPutCopyFolder(self):
        try:
            response = self.storageApi.PutCreateFolder('mytestfolder')
            response = self.storageApi.PutCopyFolder('mytestfolder','mytestfolder1')
            self.assertIsInstance(response,ResponseMessage.ResponseMessage)
            self.assertEqual(response.Status,'OK')
        except ApiException as ex:
            print "Exception"
            print "Code: " + str(ex.code)
            print "Mesage: " + ex.message
            raise ex

    def testGetIsStorageExist(self):
        try:
            response = self.storageApi.GetIsStorageExist('Aspose123')
            self.assertIsInstance(response,StorageExistResponse.StorageExistResponse)
            self.assertEqual(response.Status,'OK')
        except ApiException as ex:
            print "Exception"
            print "Code: " + str(ex.code)
            print "Mesage: " + ex.message
            raise ex

    def testGetListFileVersions(self):
        try:
            response = self.storageApi.PutCreate('testfile.txt','./data/testfile.txt')
            response = self.storageApi.GetListFileVersions('testfile.txt')

            self.assertIsInstance(response,FileVersionsResponse.FileVersionsResponse)
            self.assertEqual(response.Status,'OK')

        except ApiException as ex:
            print "Exception"
            print "Code: " + str(ex.code)
            print "Mesage: " + ex.message
            raise ex

    def testDeleteFolder(self):
        try:
            response = self.storageApi.DeleteFolder('mytestfolder')
            self.assertIsInstance(response,RemoveFolderResponse.RemoveFolderResponse)
            self.assertEqual(response.Status,'OK')

        except ApiException as ex:
            print "Exception"
            print "Code: " + str(ex.code)
            print "Mesage: " + ex.message
            raise ex

    def testDeleteFile(self):
        try:
            response = self.storageApi.DeleteFile('testfile.txt')

            self.assertIsInstance(response,RemoveFileResponse.RemoveFileResponse)
            self.assertEqual(response.Status,'OK')
        except ApiException as ex:
            print "Exception"
            print "Code: " + str(ex.code)
            print "Mesage: " + ex.message
            raise ex




#!/usr/bin/env python

class DateTime(object):
    """NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually."""


    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {
            'Year': 'int',
            'Month': 'int',
            'Day': 'int',
            'Hour': 'int',
            'Minute': 'int',
            'Second': 'int',
            'Millisecond': 'int',
            'DayOfWeek': 'str',
            'DayOfYear': 'int',
            'Kind': 'str',
            'Ticks': 'long',
            'TimeOfDay': 'str'

        }

        self.attributeMap = {
            'Year': 'Year','Month': 'Month','Day': 'Day','Hour': 'Hour','Minute': 'Minute','Second': 'Second','Millisecond': 'Millisecond','DayOfWeek': 'DayOfWeek','DayOfYear': 'DayOfYear','Kind': 'Kind','Ticks': 'Ticks','TimeOfDay': 'TimeOfDay'}       

        self.Year = None # int
        self.Month = None # int
        self.Day = None # int
        self.Hour = None # int
        self.Minute = None # int
        self.Second = None # int
        self.Millisecond = None # int
        self.DayOfWeek = None # str
        self.DayOfYear = None # int
        self.Kind = None # str
        self.Ticks = None # long
        self.TimeOfDay = None # str
        



#!/usr/bin/env python

import sys
import os
import re
import string
import urllib
import urllib2
import httplib
import json
import datetime
import mimetypes
import random
import string
import hmac
import hashlib
import requests
import httplib
import logging

from models import *
from urlparse import urlparse
from requests.utils import quote


class ApiClient(object):
    def __init__(self, apiKey=None, appSid=None, debug=False, apiServer='http://api.aspose.com/v1.1'):
        if apiKey == None:
            raise Exception('You must pass an apiKey when instantiating the '
                            'APIClient')
        if appSid == None:
            raise Exception('You must pass an apiKey when instantiating the '
                            'appSid')
        if apiServer == None:
            raise Exception('You must pass an apiKey when instantiating the '
                            'apiServer')

        self.apiKey = apiKey
        self.apiServer = apiServer
        self.appSid = appSid
        self.cookie = None
        self.defaultHeaders = {}
        self.boundary = 'Somthing'
        self.debug = debug

        if self.debug == True:
            httplib.HTTPConnection.debuglevel = 1
            logging.basicConfig() # you need to initialize logging, otherwise you will not see anything from requests
            logging.getLogger().setLevel(logging.DEBUG)
            requests_log = logging.getLogger("requests.packages.urllib3")
            requests_log.setLevel(logging.DEBUG)
            requests_log.propagate = True

    @property
    def user_agent(self):
        return self.defaultHeaders['User-Agent']

    @user_agent.setter
    def user_agent(self, value):
        self.defaultHeaders['User-Agent'] = value

    def setDefaultHeader(self, headerName, headerValue):
        self.defaultHeaders[headerName] = headerValue

    @staticmethod
    def build_uri(path, qry_data=None):
        """
        URI Builder - Accept path and query string to generate a URI.

        :param path: e.g http://api.aspose.com/v1/testurl
        :param qry_data: a dictionary which holds query string data e.g {'param1': 'value1', 'param2': 'value2'}
        :return: returns a uri with query string e.g http://api.aspose.com/v1/testurl?param1=value1&param2=value2
        """

        del_dict = {}


        if 'file' in qry_data:
            del qry_data['file']
        
        for (key, val) in qry_data.iteritems():
            if(path.find('{' + key.lower() + '}') >= 0):
                path = path.replace('{' + key.lower() + '}', val)
                del_dict[key] = val

        for (key, val) in del_dict.iteritems():
            del qry_data[key]

        path = path.rstrip('/')

        if qry_data:
            return path + '?' + urllib.urlencode(qry_data)
        else:
            return path

    def sign(self, url_to_sign, appSid, apiKey):

        url_to_sign = url_to_sign.replace(" ", "%20");

        url = urlparse(url_to_sign);

        if url.query == "":
            url_part_to_sign = url.scheme + "://" + url.netloc + url.path
        else:
            url_part_to_sign = url.scheme + "://" + url.netloc + url.path + "?" + url.query

        logging.debug("url_part_to_sign" + url_part_to_sign + "apiKey" + apiKey)
        signature = hmac.new(apiKey, url_part_to_sign, hashlib.sha1).digest().encode('base64')[:-1]
        signature = re.sub('[=_-]', '', signature)
        signature = quote(signature, safe='')

        if url.query == "":
            return url.scheme + "://" + url.netloc + url.path + "?signature=" + signature
        else:
            return url.scheme + "://" + url.netloc + url.path + "?" + url.query + "&signature=" + signature



    def callAPI(self, resourcePath, method, queryParams, postData, headerParams=None, files=None):

        resourcePath = resourcePath.replace("{" + "appSid" + "}" , self.appSid)        
        resourcePath = re.sub("\\{\\w*\\}", "", resourcePath)

        url = self.apiServer + resourcePath
        url =    self.sign(url, self.appSid, self.apiKey)
        logging.debug(url)

        mergedHeaderParams = self.defaultHeaders.copy()
        mergedHeaderParams.update(headerParams)
        headers = {}
        if mergedHeaderParams:
            for param, value in mergedHeaderParams.iteritems():
                headers[param] = ApiClient.sanitizeForSerialization(value)

        if self.cookie:
            headers['Cookie'] = ApiClient.sanitizeForSerialization(self.cookie)

        data = None

        if method in ['GET']:
            #Options to add statements later on and for compatibility
            pass

        elif method in ['POST', 'PUT', 'DELETE']:
            if postData:
                postData = ApiClient.sanitizeForSerialization(postData)
                if 'Content-type' not in headers:
                    headers['Content-type'] = 'application/json'
                    data = json.dumps(postData)
                elif headers['Content-type'] == 'multipart/form-data':
                    data = self.buildMultipartFormData(postData, files)

                    headers['Content-type'] = 'multipart/form-data; boundary={0}'.format(self.boundary)
                    headers['Content-length'] = str(len(data))
                else:
                    data = urllib.urlencode(postData)
            elif files:
                headers['Content-type'] = 'multipart/form-data; boundary={0}'.format(self.boundary)
        else:
            raise Exception('Method ' + method + ' is not recognized.')

        if headers['Accept'].find('application/octet-stream') or files:
            stream = True
        else:
            stream = False

        if method == 'GET':
                response = requests.get(url, headers=headers, stream=stream, files=files)
        elif method == 'PUT':
            if 'file' in files and files['file'] and len(files) == 1:
                response = requests.put(url,files['file'], stream=stream)
            else:
                response = requests.put(url,data,headers=headers, stream=stream, files=files)
        elif method == 'POST':
            if 'file' in files and files['file'] and len(files) == 1:
                response = requests.post(url,files['file'], stream=stream)
            else:            
                response = requests.post(url,data,headers=headers, stream=stream, files=files)
        elif method == 'DELETE':
            response = requests.delete(url,data=data,headers=headers, stream=stream, files=files)

        return response


    def toPathValue(self, obj):
        """Convert a string or object to a path-friendly value
        Args:
            obj -- object or string value
        Returns:
            string -- quoted value
        """
        if type(obj) == list:
            return ','.join(obj)
        else:
            return str(obj)

    @staticmethod
    def sanitizeForSerialization(obj):
        """
        Sanitize an object for Request.
        If obj is None, return None.
        If obj is str, int, long, float, bool, return directly.
        If obj is datetime.datetime, datetime.date convert to string in iso8601 format.
        If obj is list, santize each element in the list.
        If obj is dict, return the dict.
        If obj is swagger model, return the properties dict.
        """
        if isinstance(obj, type(None)):
            return None
        elif isinstance(obj, (str, int, long, float, bool, file)):
            return obj
        elif isinstance(obj, list):
            return [ApiClient.sanitizeForSerialization(subObj) for subObj in obj]
        elif isinstance(obj, (datetime.datetime, datetime.date)):
            return obj.isoformat()
        else:
            if isinstance(obj, dict):
                objDict = obj
            else:
            # Convert model obj to dict except attributes `swaggerTypes`, `attributeMap`
            # and attributes which value is not None.
            # Convert attribute name to json key in model definition for request.
                objDict = {obj.attributeMap[key]: val
                   for key, val in obj.__dict__.iteritems()
                   if key != 'swaggerTypes' and key != 'attributeMap' and val is not None}
            return {key: ApiClient.sanitizeForSerialization(val)
                 for (key, val) in objDict.iteritems()}

    def buildMultipartFormData(self, postData, files):
        def escape_quotes(s):
            return s.replace('"', '\\"')

        lines = []


        for name, value in postData.items():
            lines.extend((
                '--{0}'.format(self.boundary),
                'Content-Disposition: form-data; name="{0}"'.format(escape_quotes(name)),
                '',
                str(value),
             ))

        for name, filepath in files.items():
            f = open(filepath, 'r')
            filename = filepath.split('/')[-1]
            mimetype = mimetypes.guess_type(filename)[0] or 'application/octet-stream'
            lines.extend((
              '--{0}'.format(self.boundary),
              'Content-Disposition: form-data; name="{0}"; filename="{1}"'.format(escape_quotes(name), escape_quotes(filename)),
              'Content-Type: {0}'.format(mimetype),
              '',
              f.read()
            ))

        lines.extend((
          '--{0}--'.format(self.boundary),
          ''
        ))
        return '\r\n'.join(lines)

    def pre_deserialize(self, obj, objClass, contentType=None):
        
        if objClass == 'ResponseMessage':
            if contentType is not None and "application/json" not in contentType:
                objClass = eval('ResponseMessage.ResponseMessage')
                objClass.Status = 'OK'
                objClass.Code = 200
                objClass.InputStream = obj
                return objClass

        if contentType is None or "application/json" not in contentType:
            raise ApiException(406,"Invalid contentType " + str(contentType))
            
        jsonObj = json.loads(obj)
        logging.debug("JSON Body :: " + str(jsonObj))
        return self.deserialize(jsonObj, objClass)

    def deserialize(self, obj, objClass):
        """Derialize a JSON string into an object.
        Args:
            obj -- string or object to be deserialized
            objClass -- class literal for deserialzied object, or string
                of class name
        Returns:
            object -- deserialized object"""

        # Have to accept objClass as string or actual type. Type could be a
        # native Python type, or one of the model classes.
        if obj == None:
            return
         
        if type(objClass) == str:
            if 'list[' in objClass:
                match = re.match('list\[(.*)\]', objClass)
                subClass = match.group(1)
                if obj is not None:
                    return [self.deserialize(subObj, subClass) for subObj in obj]
                else:
                    return;

            if (objClass in ['int', 'float', 'long', 'dict', 'list', 'str', 'bool', 'datetime']):
                objClass = eval(objClass)
            else:  # not a native type, must be model class
                objClass = eval(objClass + '.' + objClass)

        if objClass in [int, long, float, dict, list, str, bool]:
            return objClass(obj)
        elif objClass == datetime:
            return self.__parse_string_to_datetime(obj)

        instance = objClass()

        for attr, attrType in instance.swaggerTypes.iteritems():
            logging.debug(attr + ',' + attrType)
            if obj is not None and instance.attributeMap[attr] in obj and type(obj) in [list, dict]:
                value = obj[instance.attributeMap[attr]]
                if attrType in ['str', 'int', 'long', 'float', 'bool']:
                    attrType = eval(attrType)
                    try:
                        value = attrType(value)
                    except UnicodeEncodeError:
                        value = unicode(value)
                    except TypeError:
                        value = value
                    setattr(instance, attr, value)
                elif (attrType == 'datetime'):
                    setattr(instance, attr, self.__parse_string_to_datetime(value))
                else:
                    setattr(instance, attr, self.deserialize(value, attrType))
            elif obj is not None and instance.attributeMap[attr] not in obj:
                continue
            elif 'list[' in attrType:
                match = re.match('list\[(.*)\]', attrType)
                subClass = match.group(1)
                subValues = []
                if not value:
                    setattr(instance, attr, None)
                else:
                    for subValue in value:
                        subValues.append(self.deserialize(subValue, subClass))
                setattr(instance, attr, subValues)
            else:
                value = obj[instance.attributeMap[attr]]
                setattr(instance, attr, self.deserialize(value, attrType))

        return instance

    def __parse_string_to_datetime(self, string):
        """
        Parse datetime in string to datetime.
        The string should be in iso8601 datetime format.
        """
        try:
            from dateutil.parser import parse
            return parse(string)
        except ImportError:
            return string

class ApiException(Exception):
    def __init__(self, code, message):
        self.code = code
        self.message = message

    def get_code(self):
        return self.code

    def get_message(self):
        return self.message

    def set_code(self, code):
        self.code = code

    def set_message(self, message):
        self.message = message


class MethodRequest(urllib2.Request):
    def __init__(self, *args, **kwargs):
        """Construct a MethodRequest. Usage is the same as for
        `urllib2.Request` except it also takes an optional `method`
        keyword argument. If supplied, `method` will be used instead of
        the default."""

        if 'method' in kwargs:
            self.method = kwargs.pop('method')
        return urllib2.Request.__init__(self, *args, **kwargs)

    def get_method(self):
        return getattr(self, 'method', urllib2.Request.get_method(self))




__author__ = 'farooq.sheikh'

from setuptools import setup, find_packages

setup(
    name = 'asposestoragecloud',
    packages = find_packages(),
    version = '1.0.0',
    description = 'Aspose.Storage Cloud SDK for Python allows you to use Aspose.Storage API in your Python applications',
    author='Farooq Sheikh',
    author_email='farooq.sheikh@aspose.com',
    url='https://github.com/asposetotal/Aspose_Total_Cloud/tree/master/SDKs/Aspose.Storage_Cloud_SDK_For_Python',
    classifiers=[
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent'
    ]
)



#!/usr/bin/env python

class FileDetail(object):
    """NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually."""


    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {
            'Name': 'str',
            'IsFolder': 'bool',
            'ModifiedDate': 'DateTime',
            'Size': 'long',
            'Path': 'str'

        }

        self.attributeMap = {
            'Name': 'Name','IsFolder': 'IsFolder','ModifiedDate': 'ModifiedDate','Size': 'Size','Path': 'Path'}

        self.Name = None # str
        self.IsFolder = None # bool
        self.ModifiedDate = None # DateTime
        self.Size = None # long
        self.Path = None # str
        



#!/usr/bin/env python

import sys
import os
import urllib
import json
import re
from models import *
from ApiClient import ApiException


class StorageApi(object):

    def __init__(self, apiClient):
      self.apiClient = apiClient

    

    def DeleteFile(self, Path, **kwargs):
        """Remove a specific file. Parameters: path - file path e.g. /file.ext, versionID - file's version, storage - user's storage name.
        Args:
            Path (str):  (required)

            versionId (str):  (optional)

            storage (str):  (optional)

            

        Returns: RemoveFileResponse
        """

        allParams = dict.fromkeys(['Path', 'versionId', 'storage'])

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method DeleteFile" % key)
            params[key] = val
        
        for (key, val) in params.iteritems():
            if key in allParams:
                allParams[key] = val
        
        resourcePath = '/storage/file/{path}/?appSid={appSid}&amp;versionId={versionId}&amp;storage={storage}'
        
    
        resourcePath = resourcePath.replace('&amp;','&').replace("/?","?").replace("toFormat={toFormat}","format={format}").replace("{path}","{Path}")

        if 'Path' in allParams and allParams['Path'] is not None:
            resourcePath = resourcePath.replace("{" + "Path" + "}" , str(allParams['Path']))
        else:
            resourcePath = re.sub("[&?]Path.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'versionId' in allParams and allParams['versionId'] is not None:
            resourcePath = resourcePath.replace("{" + "versionId" + "}" , str(allParams['versionId']))
        else:
            resourcePath = re.sub("[&?]versionId.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'storage' in allParams and allParams['storage'] is not None:
            resourcePath = resourcePath.replace("{" + "storage" + "}" , str(allParams['storage']))
        else:
            resourcePath = re.sub("[&?]storage.*?(?=&|\\?|$)", "", resourcePath)
        

        method = 'DELETE'
        queryParams = {}
        headerParams = {}
        formParams = {}
        files = { }
        bodyParam = None

        headerParams['Accept'] = 'application/xml,application/json'
        headerParams['Content-Type'] = 'application/json'

        postData = (formParams if formParams else bodyParam)

        response =  self.apiClient.callAPI(resourcePath, method, queryParams, postData, headerParams, files=files)

        try:
            if response.status_code in [200,201,202]:
                responseObject = self.apiClient.pre_deserialize(response.content, 'RemoveFileResponse', response.headers['content-type'])
                return responseObject
            else:
                raise ApiException(response.status_code,response.content)
        except Exception:
            raise ApiException(response.status_code,response.content)

        

        

    def GetDiscUsage(self, **kwargs):
        """Check the disk usage of the current account. Parameters: storage - user's storage name.
        Args:
            storage (str):  (optional)

            

        Returns: DiscUsageResponse
        """

        allParams = dict.fromkeys(['storage'])

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method GetDiscUsage" % key)
            params[key] = val
        
        for (key, val) in params.iteritems():
            if key in allParams:
                allParams[key] = val
        
        resourcePath = '/storage/disc/?appSid={appSid}&amp;storage={storage}'
        
    
        resourcePath = resourcePath.replace('&amp;','&').replace("/?","?").replace("toFormat={toFormat}","format={format}").replace("{path}","{Path}")

        if 'storage' in allParams and allParams['storage'] is not None:
            resourcePath = resourcePath.replace("{" + "storage" + "}" , str(allParams['storage']))
        else:
            resourcePath = re.sub("[&?]storage.*?(?=&|\\?|$)", "", resourcePath)
        

        method = 'GET'
        queryParams = {}
        headerParams = {}
        formParams = {}
        files = { }
        bodyParam = None

        headerParams['Accept'] = 'application/xml,application/json'
        headerParams['Content-Type'] = 'application/json'

        postData = (formParams if formParams else bodyParam)

        response =  self.apiClient.callAPI(resourcePath, method, queryParams, postData, headerParams, files=files)

        try:
            if response.status_code in [200,201,202]:
                responseObject = self.apiClient.pre_deserialize(response.content, 'DiscUsageResponse', response.headers['content-type'])
                return responseObject
            else:
                raise ApiException(response.status_code,response.content)
        except Exception:
            raise ApiException(response.status_code,response.content)

        

        

    def GetDownload(self, Path, **kwargs):
        """Download a specific file. Parameters: path - file path e.g. /file.ext, versionID - file's version, storage - user's storage name.
        Args:
            Path (str):  (required)

            versionId (str):  (optional)

            storage (str):  (optional)

            

        Returns: ResponseMessage
        """

        allParams = dict.fromkeys(['Path', 'versionId', 'storage'])

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method GetDownload" % key)
            params[key] = val
        
        for (key, val) in params.iteritems():
            if key in allParams:
                allParams[key] = val
        
        resourcePath = '/storage/file/{path}/?appSid={appSid}&amp;versionId={versionId}&amp;storage={storage}'
        
    
        resourcePath = resourcePath.replace('&amp;','&').replace("/?","?").replace("toFormat={toFormat}","format={format}").replace("{path}","{Path}")

        if 'Path' in allParams and allParams['Path'] is not None:
            resourcePath = resourcePath.replace("{" + "Path" + "}" , str(allParams['Path']))
        else:
            resourcePath = re.sub("[&?]Path.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'versionId' in allParams and allParams['versionId'] is not None:
            resourcePath = resourcePath.replace("{" + "versionId" + "}" , str(allParams['versionId']))
        else:
            resourcePath = re.sub("[&?]versionId.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'storage' in allParams and allParams['storage'] is not None:
            resourcePath = resourcePath.replace("{" + "storage" + "}" , str(allParams['storage']))
        else:
            resourcePath = re.sub("[&?]storage.*?(?=&|\\?|$)", "", resourcePath)
        

        method = 'GET'
        queryParams = {}
        headerParams = {}
        formParams = {}
        files = { }
        bodyParam = None

        headerParams['Accept'] = 'application/xml,application/octet-stream'
        headerParams['Content-Type'] = 'application/json'

        postData = (formParams if formParams else bodyParam)

        response =  self.apiClient.callAPI(resourcePath, method, queryParams, postData, headerParams, files=files)

        try:
            if response.status_code in [200,201,202]:
                responseObject = self.apiClient.pre_deserialize(response.content, 'ResponseMessage', response.headers['content-type'])
                return responseObject
            else:
                raise ApiException(response.status_code,response.content)
        except Exception:
            raise ApiException(response.status_code,response.content)

        

        

    def GetIsExist(self, Path, **kwargs):
        """Check if a specific file or folder exists. Parameters: path - file or folder path e.g. /file.ext or /Folder1, versionID - file's version, storage - user's storage name.
        Args:
            Path (str):  (required)

            versionId (str):  (optional)

            storage (str):  (optional)

            

        Returns: FileExistResponse
        """

        allParams = dict.fromkeys(['Path', 'versionId', 'storage'])

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method GetIsExist" % key)
            params[key] = val
        
        for (key, val) in params.iteritems():
            if key in allParams:
                allParams[key] = val
        
        resourcePath = '/storage/exist/{path}/?appSid={appSid}&amp;versionId={versionId}&amp;storage={storage}'
        
    
        resourcePath = resourcePath.replace('&amp;','&').replace("/?","?").replace("toFormat={toFormat}","format={format}").replace("{path}","{Path}")

        if 'Path' in allParams and allParams['Path'] is not None:
            resourcePath = resourcePath.replace("{" + "Path" + "}" , str(allParams['Path']))
        else:
            resourcePath = re.sub("[&?]Path.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'versionId' in allParams and allParams['versionId'] is not None:
            resourcePath = resourcePath.replace("{" + "versionId" + "}" , str(allParams['versionId']))
        else:
            resourcePath = re.sub("[&?]versionId.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'storage' in allParams and allParams['storage'] is not None:
            resourcePath = resourcePath.replace("{" + "storage" + "}" , str(allParams['storage']))
        else:
            resourcePath = re.sub("[&?]storage.*?(?=&|\\?|$)", "", resourcePath)
        

        method = 'GET'
        queryParams = {}
        headerParams = {}
        formParams = {}
        files = { }
        bodyParam = None

        headerParams['Accept'] = 'application/xml,application/json'
        headerParams['Content-Type'] = 'application/json'

        postData = (formParams if formParams else bodyParam)

        response =  self.apiClient.callAPI(resourcePath, method, queryParams, postData, headerParams, files=files)

        try:
            if response.status_code in [200,201,202]:
                responseObject = self.apiClient.pre_deserialize(response.content, 'FileExistResponse', response.headers['content-type'])
                return responseObject
            else:
                raise ApiException(response.status_code,response.content)
        except Exception:
            raise ApiException(response.status_code,response.content)

        

        

    def GetListFileVersions(self, Path, **kwargs):
        """Get the file's versions list. Parameters: path - file path e.g. /file.ext or /Folder1/file.ext, storage - user's storage name.
        Args:
            Path (str):  (required)

            storage (str):  (optional)

            

        Returns: FileVersionsResponse
        """

        allParams = dict.fromkeys(['Path', 'storage'])

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method GetListFileVersions" % key)
            params[key] = val
        
        for (key, val) in params.iteritems():
            if key in allParams:
                allParams[key] = val
        
        resourcePath = '/storage/version/{path}/?appSid={appSid}&amp;storage={storage}'
        
    
        resourcePath = resourcePath.replace('&amp;','&').replace("/?","?").replace("toFormat={toFormat}","format={format}").replace("{path}","{Path}")

        if 'Path' in allParams and allParams['Path'] is not None:
            resourcePath = resourcePath.replace("{" + "Path" + "}" , str(allParams['Path']))
        else:
            resourcePath = re.sub("[&?]Path.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'storage' in allParams and allParams['storage'] is not None:
            resourcePath = resourcePath.replace("{" + "storage" + "}" , str(allParams['storage']))
        else:
            resourcePath = re.sub("[&?]storage.*?(?=&|\\?|$)", "", resourcePath)
        

        method = 'GET'
        queryParams = {}
        headerParams = {}
        formParams = {}
        files = { }
        bodyParam = None

        headerParams['Accept'] = 'application/xml,application/json'
        headerParams['Content-Type'] = 'application/json'

        postData = (formParams if formParams else bodyParam)

        response =  self.apiClient.callAPI(resourcePath, method, queryParams, postData, headerParams, files=files)

        try:
            if response.status_code in [200,201,202]:
                responseObject = self.apiClient.pre_deserialize(response.content, 'FileVersionsResponse', response.headers['content-type'])
                return responseObject
            else:
                raise ApiException(response.status_code,response.content)
        except Exception:
            raise ApiException(response.status_code,response.content)

        

        

    def PostMoveFile(self, src, dest, **kwargs):
        """Move a specific file.
        Args:
            src (str): source file path e.g. /file.ext (required)

            dest (str):  (required)

            versionId (str): source file's version, (optional)

            storage (str): user's source storage name (optional)

            destStorage (str): user's destination storage name (optional)

            

        Returns: MoveFileResponse
        """

        allParams = dict.fromkeys(['src', 'dest', 'versionId', 'storage', 'destStorage'])

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method PostMoveFile" % key)
            params[key] = val
        
        for (key, val) in params.iteritems():
            if key in allParams:
                allParams[key] = val
        
        resourcePath = '/storage/file/{src}/?dest={dest}&amp;appSid={appSid}&amp;versionId={versionId}&amp;storage={storage}&amp;destStorage={destStorage}'
        
    
        resourcePath = resourcePath.replace('&amp;','&').replace("/?","?").replace("toFormat={toFormat}","format={format}").replace("{path}","{Path}")

        if 'src' in allParams and allParams['src'] is not None:
            resourcePath = resourcePath.replace("{" + "src" + "}" , str(allParams['src']))
        else:
            resourcePath = re.sub("[&?]src.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'dest' in allParams and allParams['dest'] is not None:
            resourcePath = resourcePath.replace("{" + "dest" + "}" , str(allParams['dest']))
        else:
            resourcePath = re.sub("[&?]dest.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'versionId' in allParams and allParams['versionId'] is not None:
            resourcePath = resourcePath.replace("{" + "versionId" + "}" , str(allParams['versionId']))
        else:
            resourcePath = re.sub("[&?]versionId.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'storage' in allParams and allParams['storage'] is not None:
            resourcePath = resourcePath.replace("{" + "storage" + "}" , str(allParams['storage']))
        else:
            resourcePath = re.sub("[&?]storage.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'destStorage' in allParams and allParams['destStorage'] is not None:
            resourcePath = resourcePath.replace("{" + "destStorage" + "}" , str(allParams['destStorage']))
        else:
            resourcePath = re.sub("[&?]destStorage.*?(?=&|\\?|$)", "", resourcePath)
        

        method = 'POST'
        queryParams = {}
        headerParams = {}
        formParams = {}
        files = { }
        bodyParam = None

        headerParams['Accept'] = 'application/xml,application/json'
        headerParams['Content-Type'] = 'application/json'

        postData = (formParams if formParams else bodyParam)

        response =  self.apiClient.callAPI(resourcePath, method, queryParams, postData, headerParams, files=files)

        try:
            if response.status_code in [200,201,202]:
                responseObject = self.apiClient.pre_deserialize(response.content, 'MoveFileResponse', response.headers['content-type'])
                return responseObject
            else:
                raise ApiException(response.status_code,response.content)
        except Exception:
            raise ApiException(response.status_code,response.content)

        

        

    def PutCopy(self, Path, newdest, file, **kwargs):
        """Copy a specific file. Parameters: path - source file path e.g. /file.ext, versionID - source file's version, storage - user's source storage name, newdest - destination file path, destStorage - user's destination storage name.
        Args:
            Path (str):  (required)

            newdest (str):  (required)

            versionId (str):  (optional)

            storage (str):  (optional)

            destStorage (str):  (optional)

            file (File):  (required)

            

        Returns: ResponseMessage
        """

        allParams = dict.fromkeys(['Path', 'newdest', 'versionId', 'storage', 'destStorage', 'file'])

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method PutCopy" % key)
            params[key] = val
        
        for (key, val) in params.iteritems():
            if key in allParams:
                allParams[key] = val
        
        resourcePath = '/storage/file/{path}/?appSid={appSid}&amp;newdest={newdest}&amp;versionId={versionId}&amp;storage={storage}&amp;destStorage={destStorage}'
        
    
        resourcePath = resourcePath.replace('&amp;','&').replace("/?","?").replace("toFormat={toFormat}","format={format}").replace("{path}","{Path}")

        if 'Path' in allParams and allParams['Path'] is not None:
            resourcePath = resourcePath.replace("{" + "Path" + "}" , str(allParams['Path']))
        else:
            resourcePath = re.sub("[&?]Path.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'newdest' in allParams and allParams['newdest'] is not None:
            resourcePath = resourcePath.replace("{" + "newdest" + "}" , str(allParams['newdest']))
        else:
            resourcePath = re.sub("[&?]newdest.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'versionId' in allParams and allParams['versionId'] is not None:
            resourcePath = resourcePath.replace("{" + "versionId" + "}" , str(allParams['versionId']))
        else:
            resourcePath = re.sub("[&?]versionId.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'storage' in allParams and allParams['storage'] is not None:
            resourcePath = resourcePath.replace("{" + "storage" + "}" , str(allParams['storage']))
        else:
            resourcePath = re.sub("[&?]storage.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'destStorage' in allParams and allParams['destStorage'] is not None:
            resourcePath = resourcePath.replace("{" + "destStorage" + "}" , str(allParams['destStorage']))
        else:
            resourcePath = re.sub("[&?]destStorage.*?(?=&|\\?|$)", "", resourcePath)
        

        method = 'PUT'
        queryParams = {}
        headerParams = {}
        formParams = {}
        files = { 'file':open(file, 'rb')}
        bodyParam = None

        headerParams['Accept'] = 'application/xml,application/json'
        headerParams['Content-Type'] = 'multipart/form-data'

        postData = (formParams if formParams else bodyParam)

        response =  self.apiClient.callAPI(resourcePath, method, queryParams, postData, headerParams, files=files)

        try:
            if response.status_code in [200,201,202]:
                responseObject = self.apiClient.pre_deserialize(response.content, 'ResponseMessage', response.headers['content-type'])
                return responseObject
            else:
                raise ApiException(response.status_code,response.content)
        except Exception:
            raise ApiException(response.status_code,response.content)

        

        

    def PutCreate(self, Path, file, **kwargs):
        """Upload a specific file. Parameters: path - source file path e.g. /file.ext, versionID - source file's version, storage - user's source storage name, newdest - destination file path, destStorage - user's destination storage name.
        Args:
            Path (str):  (required)

            versionId (str):  (optional)

            storage (str):  (optional)

            file (File):  (required)

            

        Returns: ResponseMessage
        """

        allParams = dict.fromkeys(['Path', 'versionId', 'storage', 'file'])

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method PutCreate" % key)
            params[key] = val
        
        for (key, val) in params.iteritems():
            if key in allParams:
                allParams[key] = val
        
        resourcePath = '/storage/file/{path}/?appSid={appSid}&amp;versionId={versionId}&amp;storage={storage}'
        
    
        resourcePath = resourcePath.replace('&amp;','&').replace("/?","?").replace("toFormat={toFormat}","format={format}").replace("{path}","{Path}")

        if 'Path' in allParams and allParams['Path'] is not None:
            resourcePath = resourcePath.replace("{" + "Path" + "}" , str(allParams['Path']))
        else:
            resourcePath = re.sub("[&?]Path.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'versionId' in allParams and allParams['versionId'] is not None:
            resourcePath = resourcePath.replace("{" + "versionId" + "}" , str(allParams['versionId']))
        else:
            resourcePath = re.sub("[&?]versionId.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'storage' in allParams and allParams['storage'] is not None:
            resourcePath = resourcePath.replace("{" + "storage" + "}" , str(allParams['storage']))
        else:
            resourcePath = re.sub("[&?]storage.*?(?=&|\\?|$)", "", resourcePath)
        

        method = 'PUT'
        queryParams = {}
        headerParams = {}
        formParams = {}
        files = { 'file':open(file, 'rb')}
        bodyParam = None

        headerParams['Accept'] = 'application/xml,application/json'
        headerParams['Content-Type'] = 'multipart/form-data'

        postData = (formParams if formParams else bodyParam)

        response =  self.apiClient.callAPI(resourcePath, method, queryParams, postData, headerParams, files=files)

        try:
            if response.status_code in [200,201,202]:
                responseObject = self.apiClient.pre_deserialize(response.content, 'ResponseMessage', response.headers['content-type'])
                return responseObject
            else:
                raise ApiException(response.status_code,response.content)
        except Exception:
            raise ApiException(response.status_code,response.content)

        

        

    def DeleteFolder(self, Path, **kwargs):
        """Remove a specific folder. Parameters: path - folder path e.g. /Folder1, storage - user's storage name, recursive - is subfolders and files must be deleted for specified path.
        Args:
            Path (str):  (required)

            storage (str):  (optional)

            recursive (bool):  (optional)

            

        Returns: RemoveFolderResponse
        """

        allParams = dict.fromkeys(['Path', 'storage', 'recursive'])

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method DeleteFolder" % key)
            params[key] = val
        
        for (key, val) in params.iteritems():
            if key in allParams:
                allParams[key] = val
        
        resourcePath = '/storage/folder/{path}/?appSid={appSid}&amp;storage={storage}&amp;recursive={recursive}'
        
    
        resourcePath = resourcePath.replace('&amp;','&').replace("/?","?").replace("toFormat={toFormat}","format={format}").replace("{path}","{Path}")

        if 'Path' in allParams and allParams['Path'] is not None:
            resourcePath = resourcePath.replace("{" + "Path" + "}" , str(allParams['Path']))
        else:
            resourcePath = re.sub("[&?]Path.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'storage' in allParams and allParams['storage'] is not None:
            resourcePath = resourcePath.replace("{" + "storage" + "}" , str(allParams['storage']))
        else:
            resourcePath = re.sub("[&?]storage.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'recursive' in allParams and allParams['recursive'] is not None:
            resourcePath = resourcePath.replace("{" + "recursive" + "}" , str(allParams['recursive']))
        else:
            resourcePath = re.sub("[&?]recursive.*?(?=&|\\?|$)", "", resourcePath)
        

        method = 'DELETE'
        queryParams = {}
        headerParams = {}
        formParams = {}
        files = { }
        bodyParam = None

        headerParams['Accept'] = 'application/xml,application/json'
        headerParams['Content-Type'] = 'application/json'

        postData = (formParams if formParams else bodyParam)

        response =  self.apiClient.callAPI(resourcePath, method, queryParams, postData, headerParams, files=files)

        try:
            if response.status_code in [200,201,202]:
                responseObject = self.apiClient.pre_deserialize(response.content, 'RemoveFolderResponse', response.headers['content-type'])
                return responseObject
            else:
                raise ApiException(response.status_code,response.content)
        except Exception:
            raise ApiException(response.status_code,response.content)

        

        

    def GetListFiles(self, **kwargs):
        """Get the file listing of a specific folder. Parametres: path - start with name of storage e.g. root folder '/'or some folder '/folder1/..', storage - user's storage name.
        Args:
            Path (str):  (optional)

            storage (str):  (optional)

            

        Returns: FilesResponse
        """

        allParams = dict.fromkeys(['Path', 'storage'])

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method GetListFiles" % key)
            params[key] = val
        
        for (key, val) in params.iteritems():
            if key in allParams:
                allParams[key] = val
        
        resourcePath = '/storage/folder/{path}/?appSid={appSid}&amp;storage={storage}'
        
    
        resourcePath = resourcePath.replace('&amp;','&').replace("/?","?").replace("toFormat={toFormat}","format={format}").replace("{path}","{Path}")

        if 'Path' in allParams and allParams['Path'] is not None:
            resourcePath = resourcePath.replace("{" + "Path" + "}" , str(allParams['Path']))
        else:
            resourcePath = re.sub("[&?]Path.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'storage' in allParams and allParams['storage'] is not None:
            resourcePath = resourcePath.replace("{" + "storage" + "}" , str(allParams['storage']))
        else:
            resourcePath = re.sub("[&?]storage.*?(?=&|\\?|$)", "", resourcePath)
        

        method = 'GET'
        queryParams = {}
        headerParams = {}
        formParams = {}
        files = { }
        bodyParam = None

        headerParams['Accept'] = 'application/xml,application/json'
        headerParams['Content-Type'] = 'application/json'

        postData = (formParams if formParams else bodyParam)

        response =  self.apiClient.callAPI(resourcePath, method, queryParams, postData, headerParams, files=files)

        try:
            if response.status_code in [200,201,202]:
                responseObject = self.apiClient.pre_deserialize(response.content, 'FilesResponse', response.headers['content-type'])
                return responseObject
            else:
                raise ApiException(response.status_code,response.content)
        except Exception:
            raise ApiException(response.status_code,response.content)

        

        

    def PostMoveFolder(self, src, dest, **kwargs):
        """Move a specific folder. Parameters: src - source folder path e.g. /Folder1, storage - user's source storage name, dest - destination folder path e.g. /Folder2, destStorage - user's destination storage name.
        Args:
            src (str):  (required)

            dest (str):  (required)

            storage (str):  (optional)

            destStorage (str):  (optional)

            

        Returns: MoveFolderResponse
        """

        allParams = dict.fromkeys(['src', 'dest', 'storage', 'destStorage'])

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method PostMoveFolder" % key)
            params[key] = val
        
        for (key, val) in params.iteritems():
            if key in allParams:
                allParams[key] = val
        
        resourcePath = '/storage/folder/{src}/?dest={dest}&amp;appSid={appSid}&amp;storage={storage}&amp;destStorage={destStorage}'
        
    
        resourcePath = resourcePath.replace('&amp;','&').replace("/?","?").replace("toFormat={toFormat}","format={format}").replace("{path}","{Path}")

        if 'src' in allParams and allParams['src'] is not None:
            resourcePath = resourcePath.replace("{" + "src" + "}" , str(allParams['src']))
        else:
            resourcePath = re.sub("[&?]src.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'dest' in allParams and allParams['dest'] is not None:
            resourcePath = resourcePath.replace("{" + "dest" + "}" , str(allParams['dest']))
        else:
            resourcePath = re.sub("[&?]dest.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'storage' in allParams and allParams['storage'] is not None:
            resourcePath = resourcePath.replace("{" + "storage" + "}" , str(allParams['storage']))
        else:
            resourcePath = re.sub("[&?]storage.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'destStorage' in allParams and allParams['destStorage'] is not None:
            resourcePath = resourcePath.replace("{" + "destStorage" + "}" , str(allParams['destStorage']))
        else:
            resourcePath = re.sub("[&?]destStorage.*?(?=&|\\?|$)", "", resourcePath)
        

        method = 'POST'
        queryParams = {}
        headerParams = {}
        formParams = {}
        files = { }
        bodyParam = None

        headerParams['Accept'] = 'application/xml,application/json'
        headerParams['Content-Type'] = 'application/json'

        postData = (formParams if formParams else bodyParam)

        response =  self.apiClient.callAPI(resourcePath, method, queryParams, postData, headerParams, files=files)

        try:
            if response.status_code in [200,201,202]:
                responseObject = self.apiClient.pre_deserialize(response.content, 'MoveFolderResponse', response.headers['content-type'])
                return responseObject
            else:
                raise ApiException(response.status_code,response.content)
        except Exception:
            raise ApiException(response.status_code,response.content)

        

        

    def PutCopyFolder(self, Path, newdest, **kwargs):
        """Copy a folder. Parameters: path - source folder path e.g. /Folder1, storage - user's source storage name, newdest - destination folder path e.g. /Folder2, destStorage - user's destination storage name.
        Args:
            Path (str):  (required)

            newdest (str):  (required)

            storage (str):  (optional)

            destStorage (str):  (optional)

            

        Returns: ResponseMessage
        """

        allParams = dict.fromkeys(['Path', 'newdest', 'storage', 'destStorage'])

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method PutCopyFolder" % key)
            params[key] = val
        
        for (key, val) in params.iteritems():
            if key in allParams:
                allParams[key] = val
        
        resourcePath = '/storage/folder/{path}/?appSid={appSid}&amp;newdest={newdest}&amp;storage={storage}&amp;destStorage={destStorage}'
        
    
        resourcePath = resourcePath.replace('&amp;','&').replace("/?","?").replace("toFormat={toFormat}","format={format}").replace("{path}","{Path}")

        if 'Path' in allParams and allParams['Path'] is not None:
            resourcePath = resourcePath.replace("{" + "Path" + "}" , str(allParams['Path']))
        else:
            resourcePath = re.sub("[&?]Path.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'newdest' in allParams and allParams['newdest'] is not None:
            resourcePath = resourcePath.replace("{" + "newdest" + "}" , str(allParams['newdest']))
        else:
            resourcePath = re.sub("[&?]newdest.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'storage' in allParams and allParams['storage'] is not None:
            resourcePath = resourcePath.replace("{" + "storage" + "}" , str(allParams['storage']))
        else:
            resourcePath = re.sub("[&?]storage.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'destStorage' in allParams and allParams['destStorage'] is not None:
            resourcePath = resourcePath.replace("{" + "destStorage" + "}" , str(allParams['destStorage']))
        else:
            resourcePath = re.sub("[&?]destStorage.*?(?=&|\\?|$)", "", resourcePath)
        

        method = 'PUT'
        queryParams = {}
        headerParams = {}
        formParams = {}
        files = { }
        bodyParam = None

        headerParams['Accept'] = 'application/xml,application/json'
        headerParams['Content-Type'] = 'application/json'

        postData = (formParams if formParams else bodyParam)

        response =  self.apiClient.callAPI(resourcePath, method, queryParams, postData, headerParams, files=files)

        try:
            if response.status_code in [200,201,202]:
                responseObject = self.apiClient.pre_deserialize(response.content, 'ResponseMessage', response.headers['content-type'])
                return responseObject
            else:
                raise ApiException(response.status_code,response.content)
        except Exception:
            raise ApiException(response.status_code,response.content)

        

        

    def PutCreateFolder(self, Path, **kwargs):
        """Create the folder. Parameters: path - source folder path e.g. /Folder1, storage - user's source storage name, newdest - destination folder path e.g. /Folder2, destStorage - user's destination storage name.
        Args:
            Path (str):  (required)

            storage (str):  (optional)

            destStorage (str):  (optional)

            

        Returns: ResponseMessage
        """

        allParams = dict.fromkeys(['Path', 'storage', 'destStorage'])

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method PutCreateFolder" % key)
            params[key] = val
        
        for (key, val) in params.iteritems():
            if key in allParams:
                allParams[key] = val
        
        resourcePath = '/storage/folder/{path}/?appSid={appSid}&amp;storage={storage}&amp;destStorage={destStorage}'
        
    
        resourcePath = resourcePath.replace('&amp;','&').replace("/?","?").replace("toFormat={toFormat}","format={format}").replace("{path}","{Path}")

        if 'Path' in allParams and allParams['Path'] is not None:
            resourcePath = resourcePath.replace("{" + "Path" + "}" , str(allParams['Path']))
        else:
            resourcePath = re.sub("[&?]Path.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'storage' in allParams and allParams['storage'] is not None:
            resourcePath = resourcePath.replace("{" + "storage" + "}" , str(allParams['storage']))
        else:
            resourcePath = re.sub("[&?]storage.*?(?=&|\\?|$)", "", resourcePath)
        

        if 'destStorage' in allParams and allParams['destStorage'] is not None:
            resourcePath = resourcePath.replace("{" + "destStorage" + "}" , str(allParams['destStorage']))
        else:
            resourcePath = re.sub("[&?]destStorage.*?(?=&|\\?|$)", "", resourcePath)
        

        method = 'PUT'
        queryParams = {}
        headerParams = {}
        formParams = {}
        files = { }
        bodyParam = None

        headerParams['Accept'] = 'application/xml,application/json'
        headerParams['Content-Type'] = 'application/json'

        postData = (formParams if formParams else bodyParam)

        response =  self.apiClient.callAPI(resourcePath, method, queryParams, postData, headerParams, files=files)

        try:
            if response.status_code in [200,201,202]:
                responseObject = self.apiClient.pre_deserialize(response.content, 'ResponseMessage', response.headers['content-type'])
                return responseObject
            else:
                raise ApiException(response.status_code,response.content)
        except Exception:
            raise ApiException(response.status_code,response.content)

        

        

    def GetIsStorageExist(self, name, **kwargs):
        """Check if a specific storage exists.
        Args:
            name (str): Storage name (required)

            

        Returns: StorageExistResponse
        """

        allParams = dict.fromkeys(['name'])

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method GetIsStorageExist" % key)
            params[key] = val
        
        for (key, val) in params.iteritems():
            if key in allParams:
                allParams[key] = val
        
        resourcePath = '/storage/{name}/exist/?appSid={appSid}'
        
    
        resourcePath = resourcePath.replace('&amp;','&').replace("/?","?").replace("toFormat={toFormat}","format={format}").replace("{path}","{Path}")

        if 'name' in allParams and allParams['name'] is not None:
            resourcePath = resourcePath.replace("{" + "name" + "}" , str(allParams['name']))
        else:
            resourcePath = re.sub("[&?]name.*?(?=&|\\?|$)", "", resourcePath)
        

        method = 'GET'
        queryParams = {}
        headerParams = {}
        formParams = {}
        files = { }
        bodyParam = None

        headerParams['Accept'] = 'application/xml,application/json'
        headerParams['Content-Type'] = 'application/json'

        postData = (formParams if formParams else bodyParam)

        response =  self.apiClient.callAPI(resourcePath, method, queryParams, postData, headerParams, files=files)

        try:
            if response.status_code in [200,201,202]:
                responseObject = self.apiClient.pre_deserialize(response.content, 'StorageExistResponse', response.headers['content-type'])
                return responseObject
            else:
                raise ApiException(response.status_code,response.content)
        except Exception:
            raise ApiException(response.status_code,response.content)

        

        

    




